@@ -148,9 +148,9 @@ char *cat(char *a, char *b)
 void containerize(struct container *c)
 {
    if (c->join_pid) {
-      join_namespaces(c->join_pid);   
+      join_namespaces(c->join_pid);
       return;
-   } 
+   }
    if (c->join)
       join_begin(c->join_ct, c->join_tag);
    if (!c->join || join.winner_p) {
@@ -207,8 +207,9 @@ void enter_udss(struct container *c)
    // Bind-mount /usr/bin/ch-ssh if it exists.
    if (path_exists(cat(c->newroot, "/usr/bin/ch-ssh"))) {
       char chrun_file[PATH_CHARS];
-      T_ (-1 != readlink("/proc/self/exe", chrun_file, PATH_CHARS));
-      chrun_file[PATH_CHARS-1] = 0;  // guarantee string termination
+      int len = readlink("/proc/self/exe", chrun_file, PATH_CHARS);
+      T_ (len >= 0);
+      chrun_file[ len<PATH_CHARS ? len : PATH_CHARS-1 ] = 0; // terminate; #314
       bind_mount(cat(dirname(chrun_file), "/ch-ssh"), "/usr/bin/ch-ssh",
                  c->newroot, BD_REQUIRED, 0);
    }
