@@ -10,7 +10,8 @@ while true; do
     cs_ct=$($cmd | wc -l)
     echo "found $cs_ct containers"
     [[ 0 -eq $cs_ct ]] && break
-    sudo docker rm "$($cmd)"
+    # shellcheck disable=SC2046
+    sudo docker rm $($cmd)
 done
 
 # Untag all images
@@ -19,7 +20,8 @@ while true; do
     tag_ct=$($cmd | wc -l)
     echo "found $tag_ct tagged images"
     [[ 0 -eq $tag_ct ]] && break
-    sudo docker rmi -f --no-prune "$($cmd)"
+    # shellcheck disable=SC2046
+    sudo docker rmi -f --no-prune $($cmd)
 done
 
 # If --all specified, remove all images.
@@ -29,6 +31,7 @@ if [[ $1 = --all ]]; then
         img_ct=$($cmd | wc -l)
         echo "found $img_ct images"
         [[ 0 -eq $img_ct ]] && break
-        sudo docker rmi -f "$($cmd)"
+        # shellcheck disable=SC2046
+        sudo docker rmi -f $($cmd)
     done
 fi
